"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const axios = require('axios');
const error_1 = require("./error");
class ContentstackClient {
    constructor(cmaHost, authToken, limit) {
        this.instance = axios.create({
            baseURL: `https://${cmaHost}/v3/`,
            headers: {
                authtoken: authToken,
            },
        });
        this.limit = limit || 100;
    }
    async getOrganization(org_uid) {
        try {
            const response = await this.instance.get(`/organizations/${org_uid}`);
            const o = response.data.organization;
            return {
                uid: o.uid,
                name: o.name,
                enabled: o.enabled,
            };
        }
        catch (error) {
            throw this.buildError(error);
        }
    }
    async getOrganizations() {
        try {
            const response = await this.instance.get('/organizations', {
                params: {
                    asc: 'name',
                    limit: this.limit,
                },
            });
            return response.data.organizations.map((o) => {
                return {
                    uid: o.uid,
                    name: o.name,
                    enabled: o.enabled,
                };
            });
        }
        catch (error) {
            throw this.buildError(error);
        }
    }
    async getStack(stackUID) {
        try {
            const response = await this.instance.get('/stacks', {
                headers: { api_key: stackUID },
            });
            const s = response.data.stack;
            return {
                uid: s.uid,
                name: s.name,
                master_locale: s.master_locale,
                api_key: s.api_key,
                org_uid: s.org_uid,
            };
        }
        catch (error) {
            throw this.buildError(error);
        }
    }
    async getStacks(org_uid) {
        try {
            const response = await this.instance.get('/stacks', {
                params: {
                    organization_uid: org_uid,
                },
            });
            return response.data.stacks.map((s) => {
                return {
                    uid: s.uid,
                    name: s.name,
                    master_locale: s.master_locale,
                    api_key: s.api_key,
                    org_uid: s.org_uid,
                };
            });
        }
        catch (error) {
            throw this.buildError(error);
        }
    }
    async getContentTypeCount(api_key) {
        try {
            const response = await this.instance.get('/content_types', {
                params: {
                    api_key: api_key,
                    include_count: true,
                },
                headers: { api_key },
            });
            return response.data.count;
        }
        catch (error) {
            throw this.buildError(error);
        }
    }
    async createStack(options) {
        try {
            const body = {
                stack: {
                    name: options.name,
                    description: options.description,
                    master_locale: options.master_locale,
                },
            };
            const response = await this.instance.post('/stacks', body, {
                headers: {
                    'Content-Type': 'application/json',
                    organization_uid: options.org_uid,
                },
            });
            const stack = response.data.stack;
            return {
                uid: stack.uid,
                api_key: stack.api_key,
                master_locale: stack.master_locale,
                name: stack.name,
                org_uid: stack.org_uid,
            };
        }
        catch (error) {
            throw this.buildError(error);
        }
    }
    buildError(error) {
        var _a;
        const message = ((_a = error.response.data) === null || _a === void 0 ? void 0 : _a.error_message) || error.response.statusText;
        const status = error.response.status;
        return new error_1.default(message, status);
    }
}
exports.default = ContentstackClient;
